@@ -2,7 +2,10 @@ import argparse
 
 import annofabcli
 import annofabcli.common.cli
+import annofabcli.filesystem.draw_annotation
 import annofabcli.filesystem.filter_annotation
+import annofabcli.filesystem.mask_user_info
+import annofabcli.filesystem.merge_annotation
 import annofabcli.filesystem.write_annotation_image
 
 
@@ -11,7 +14,10 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers()
 
     # サブコマンドの定義
+    annofabcli.filesystem.draw_annotation.add_parser(subparsers)
     annofabcli.filesystem.filter_annotation.add_parser(subparsers)
+    annofabcli.filesystem.mask_user_info.add_parser(subparsers)
+    annofabcli.filesystem.merge_annotation.add_parser(subparsers)
     annofabcli.filesystem.write_annotation_image.add_parser(subparsers)
 
 
