@@ -17,7 +17,7 @@ import dateutil
 import dateutil.parser
 import more_itertools
 from annofabapi.dataclass.task import Task as DcTask
-from annofabapi.models import InputDataId, Inspection, JobStatus, JobType, Task, TaskHistory
+from annofabapi.models import InputDataId, Inspection, JobStatus, ProjectJobType, Task, TaskHistory
 from annofabapi.parser import SimpleAnnotationZipParser
 
 from annofabcli.common.dataclasses import WaitOptions
@@ -177,7 +177,7 @@ class Database:
     def read_inspections_from_json(self, task_id_list: List[str]) -> Dict[str, Dict[InputDataId, List[Inspection]]]:
         logger.debug(f"{self.logging_prefix}: reading {self.inspection_json_path}")
 
-        with open(str(self.inspection_json_path)) as f:
+        with open(str(self.inspection_json_path), encoding="utf-8") as f:
             all_inspections = json.load(f)
 
         tasks_dict: Dict[str, Dict[InputDataId, List[Inspection]]] = {}
@@ -203,7 +203,7 @@ class Database:
     def read_input_data_from_json(self) -> Dict[str, PseudoInputData]:
         path = self.input_data_json_path
         logger.debug(f"{self.logging_prefix}: reading {path}")
-        with open(str(path)) as f:
+        with open(str(path), encoding="utf-8") as f:
             all_input_data_list = json.load(f)
 
         all_input_data_dict = {
@@ -214,7 +214,7 @@ class Database:
 
     def read_task_histories_from_json(self, task_id_list: Optional[List[str]] = None) -> Dict[str, List[TaskHistory]]:
         logger.debug(f"{self.logging_prefix}: reading {self.task_histories_json_path}")
-        with open(str(self.task_histories_json_path)) as f:
+        with open(str(self.task_histories_json_path), encoding="utf-8") as f:
             task_histories_dict = json.load(f)
 
         if task_id_list is not None:
@@ -230,7 +230,7 @@ class Database:
         MAX_WAIT_MINUTU = MAX_JOB_ACCESS * JOB_ACCESS_INTERVAL / 60
         result = self.annofab_service.wrapper.wait_for_completion(
             project_id,
-            job_type=JobType.GEN_ANNOTATION,
+            job_type=ProjectJobType.GEN_ANNOTATION,
             job_access_interval=JOB_ACCESS_INTERVAL,
             max_job_access=MAX_JOB_ACCESS,
         )
@@ -246,7 +246,7 @@ class Database:
         MAX_WAIT_MINUTU = MAX_JOB_ACCESS * JOB_ACCESS_INTERVAL / 60
         result = self.annofab_service.wrapper.wait_for_completion(
             project_id,
-            job_type=JobType.GEN_TASKS_LIST,
+            job_type=ProjectJobType.GEN_TASKS_LIST,
             job_access_interval=JOB_ACCESS_INTERVAL,
             max_job_access=MAX_JOB_ACCESS,
         )
@@ -280,7 +280,7 @@ class Database:
         logger.debug(f"{self.logging_prefix}: アノテーション仕様の最終更新日時={annotation_specs_updated_datetime}")
 
         job_list = self.annofab_service.api.get_project_job(
-            project_id, query_params={"type": JobType.GEN_ANNOTATION.value, "limit": 1}
+            project_id, query_params={"type": ProjectJobType.GEN_ANNOTATION.value, "limit": 1}
         )[0]["list"]
         if len(job_list) > 0:
             job = job_list[0]
@@ -334,7 +334,7 @@ class Database:
         """
 
         job_list = self.annofab_service.api.get_project_job(
-            project_id, query_params={"type": JobType.GEN_TASKS_LIST.value, "limit": 1}
+            project_id, query_params={"type": ProjectJobType.GEN_TASKS_LIST.value, "limit": 1}
         )[0]["list"]
 
         if len(job_list) == 0:
@@ -379,7 +379,7 @@ class Database:
         logger.debug(f"{self.logging_prefix}: アノテーション仕様の最終更新日時={annotation_specs_updated_datetime}")
 
         job_list = self.annofab_service.api.get_project_job(
-            self.project_id, query_params={"type": JobType.GEN_ANNOTATION.value, "limit": 1}
+            self.project_id, query_params={"type": ProjectJobType.GEN_ANNOTATION.value, "limit": 1}
         )[0]["list"]
         if len(job_list) == 0:
             logger.debug(f"{self.logging_prefix}: アノテーションzipの最終更新日時は不明です。")
@@ -500,7 +500,7 @@ class Database:
             return flag
 
         logger.debug(f"{self.logging_prefix}: reading {self.tasks_json_path}")
-        with open(str(self.tasks_json_path)) as f:
+        with open(str(self.tasks_json_path), encoding="utf-8") as f:
             all_tasks = json.load(f)
 
         filtered_task_list = [task for task in all_tasks if filter_task(task)]
